#
# spec file for package dracut-pcr-signature
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dracut-pcr-signature
Version:        0.6+0
Release:        1.1
Summary:        Dracut module to import PCR signatures
License:        GPL-2.0-or-later
URL:            https://github.com/aplanas/dracut-pcr-signature
Source:         %{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  rpm-config-SUSE
BuildRequires:  pkgconfig(dracut)
BuildArch:      noarch

%description
Dracut module to import PCR signatures.  This will make possible the
prediction of the initrd (and cmdline) hashes, as will not require the
update of the initrd to introduce the JSON and PEM files required to
unlock the LUKS2 device via systemd-cryptsetup.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/dracut/modules.d/50pcr-signature
for i in module-setup.sh boot-efi-generator.sh pcr-signature.sh pcr-signature.service; do
    cp "$i" %{buildroot}%{_prefix}/lib/dracut/modules.d/50pcr-signature
done

%post
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%postun
%{?regenerate_initrd_post}

%files
%license LICENSE
%doc README.md
%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%{_prefix}/lib/dracut/modules.d/50pcr-signature

%changelog
* Fri Jan 31 2025 aplanas@suse.com
- Update to version 0.6+0:
  * Copy measure-pcr files
* Tue Dec 17 2024 aplanas@suse.com
- Update to version 0.5+1:
  * Make the mount do not depend of default service
* Thu Oct 31 2024 aplanas@suse.com
- Update to version 0.5+0:
  * Normalize spec file
  * Use a generator to mount ESP
  * Avoid race condition when multiple disks are encrypted
* Mon Oct  7 2024 aplanas@suse.com
- Update to version 0.4+2:
  * Synchronize spec file
  * Copy JSON file in /run to survive initrd
* Thu May 30 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 0.4:
  + No new features, tagged on 0.3+6
- Remove GRUB2 conflict
* Mon May 13 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Adapt regenerate initrd macro expansion
* Mon Apr 22 2024 aplanas@suse.com
- Update to version 0.3+6:
  * Add UTF8 character set
* Wed Apr 17 2024 aplanas@suse.com
- Update to version 0.3+5:
  * Generate the initrd after installation
  * Temporaly conflict with GRUB2
  * Small fix for comment
* Tue Apr 16 2024 aplanas@suse.com
- Update to version 0.3+2:
  * Do not hard fail when error in mount
* Fri Apr 12 2024 aplanas@suse.com
- Update to version 0.3+1:
  * Include mktemp in initrd
* Wed Apr 10 2024 aplanas@suse.com
- Update to version 0.3+0:
  * Various small improvements
* Tue Mar 12 2024 aplanas@suse.com
- Update to version 0.2:
  * Support GRUB2 configurations
* Tue Jan 30 2024 aplanas@suse.com
- Update to version 0.1+3:
  * Copy pcrlock.json if available
* Tue Jan  9 2024 aplanas@suse.com
- Update to version 0.1+2:
  * Explicitly add VFAT module
* Fri Dec  1 2023 aplanas@suse.com
- Update to version 0.1+1:
  * Use xz compression
* Wed Nov 29 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Initial package
